@@ -15,7 +15,9 @@ test('Dumper should not take into account booleans syntax from YAML 1.0/1.1 in n
   DEPRECATED_BOOLEANS_SYNTAX.forEach(function (string) {
     var dump = yaml.dump(string, { noCompatMode: true }).trim();
 
-    assert((dump === string),
-           ('"' + string + '" string is not dumped as-is; actual dump: ' + dump));
+    assert(
+      (dump === string),
+      ('"' + string + '" string is not dumped as-is; actual dump: ' + dump)
+    );
   });
 });
